@@ -88,6 +88,13 @@ struct LeaderSlotPacketCountMetrics {
     // queue becaus they were retryable errors
     retryable_errored_transaction_count: u64,
 
+    // The size of the unprocessed buffer at the end of the slot
+    end_of_slot_unprocessed_buffer_len: u64,
+
+    // total number of transactions that were rebuffered into the queue after not being
+    // executed on a previous pass
+    retryable_packets_count: u64,
+
     // total number of transactions that attempted execution due to some fatal error (too old, duplicate signature, etc.)
     // AND were dropped from the buffered queue
     nonretryable_errored_transactions_count: u64,
@@ -174,6 +181,11 @@ impl LeaderSlotPacketCountMetrics {
                 self.retryable_errored_transaction_count as i64,
                 i64
             ),
+            (
+                "retryable_packets_count",
+                self.retryable_packets_count as i64,
+                i64
+            ),
             (
                 "nonretryable_errored_transactions_count",
                 self.nonretryable_errored_transactions_count as i64,
@@ -214,6 +226,11 @@ impl LeaderSlotPacketCountMetrics {
                 self.end_of_slot_filtered_invalid_count as i64,
                 i64
             ),
+            (
+                "end_of_slot_unprocessed_buffer_len",
+                self.end_of_slot_unprocessed_buffer_len as i64,
+                i64
+            ),
         );
     }
 }
@@ -524,6 +541,17 @@ impl LeaderSlotMetricsTracker {
         }
     }
 
+    pub(crate) fn increment_retryable_packets_count(&mut self, count: u64) {
+        if let Some(leader_slot_metrics) = &mut self.leader_slot_metrics {
+            saturating_add_assign!(
+                leader_slot_metrics
+                    .packet_count_metrics
+                    .retryable_packets_count,
+                count
+            );
+        }
+    }
+
     pub(crate) fn increment_end_of_slot_filtered_invalid_count(&mut self, count: u64) {
         if let Some(leader_slot_metrics) = &mut self.leader_slot_metrics {
             saturating_add_assign!(
@@ -535,6 +563,14 @@ impl LeaderSlotMetricsTracker {
         }
     }
 
+    pub(crate) fn set_end_of_slot_unprocessed_buffer_len(&mut self, len: u64) {
+        if let Some(leader_slot_metrics) = &mut self.leader_slot_metrics {
+            leader_slot_metrics
+                .packet_count_metrics
+                .end_of_slot_unprocessed_buffer_len = len;
+        }
+    }
+
     // Outermost banking thread's loop timing metrics
     pub(crate) fn increment_process_buffered_packets_us(&mut self, us: u64) {
         if let Some(leader_slot_metrics) = &mut self.leader_slot_metrics {
@@ -569,6 +605,13 @@ impl LeaderSlotMetricsTracker {
                     .receive_and_buffer_packets_us,
                 us
             );
+            saturating_add_assign!(
+                leader_slot_metrics
+                    .timing_metrics
+                    .outer_loop_timings
+                    .receive_and_buffer_packets_invoked_count,
+                1
+            );
         }
     }
 
